==> haskell-tasty-expected-failure-0.12.3-490-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-expected-failure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-expected-failure
version:              0.12.3
visibility:           public
id:                   tasty-expected-failure-0.12.3-KgRiGDAsj2EGkn5Go6kxcT
key:                  tasty-expected-failure-0.12.3-KgRiGDAsj2EGkn5Go6kxcT
license:              MIT
copyright:            2015 Joachim Breitner
maintainer:           mail@joachim-breitner.de
author:               Joachim Breitner
homepage:             http://github.com/nomeata/tasty-expected-failure
synopsis:             Mark tasty tests as failure expected
description:
    With the function '\''Test.Tasty.ExpectedFailure.expectFail'\'' in the provided module
    "Test.Tasty.ExpectedFailure", you can mark that you expect test cases to fail,
    and not to pass.

    This can for example be used for test-driven development: Create the tests,
    mark them with '\''Test.Tasty.ExpectedFailure.expectFail'\'', and you can still push
    to the main branch, without your continuous integration branch failing.

    Once someone implements the feature or fixes the bug (maybe unknowingly), the
    test suite will tell him so, due to the now unexpectedly passing test, and he
    can remove the '\''Test.Tasty.ExpectedFailure.expectFail'\'' marker.

    The module also provides '\''Test.Tasty.ExpectedFailure.ignoreTest'\'' to avoid
    running a test. Both funtions are implemented via the more general
    '\''Test.Tasty.ExpectedFailure.wrapTest'\'', which is also provided.

category:             Testing
abi:                  8baf6e8920365b83baf5af06c1e8d7de
exposed:              True
exposed-modules:      Test.Tasty.ExpectedFailure
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-expected-failure-0.12.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-expected-failure-0.12.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-expected-failure-0.12.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-expected-failure
hs-libraries:         HStasty-expected-failure-0.12.3-KgRiGDAsj2EGkn5Go6kxcT
depends:
    base-4.17.2.1 tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5-Ezyjsj4s9uQ4MIGkkKZoRH
    unbounded-delays-0.1.1.1-9PQJht8VjI9BW2tiXlJWhX

haddock-interfaces:
    /usr/share/doc/haskell-tasty-expected-failure/html/tasty-expected-failure.haddock

haddock-html:         /usr/share/doc/haskell-tasty-expected-failure/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-expected-failure-0.12.3-492-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-expected-failure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-expected-failure
version:              0.12.3
visibility:           public
id:                   tasty-expected-failure-0.12.3-2B7tQ5MwpW3Qc4nmKIGHm
key:                  tasty-expected-failure-0.12.3-2B7tQ5MwpW3Qc4nmKIGHm
license:              MIT
copyright:            2015 Joachim Breitner
maintainer:           mail@joachim-breitner.de
author:               Joachim Breitner
homepage:             http://github.com/nomeata/tasty-expected-failure
synopsis:             Mark tasty tests as failure expected
description:
    With the function '\''Test.Tasty.ExpectedFailure.expectFail'\'' in the provided module
    "Test.Tasty.ExpectedFailure", you can mark that you expect test cases to fail,
    and not to pass.

    This can for example be used for test-driven development: Create the tests,
    mark them with '\''Test.Tasty.ExpectedFailure.expectFail'\'', and you can still push
    to the main branch, without your continuous integration branch failing.

    Once someone implements the feature or fixes the bug (maybe unknowingly), the
    test suite will tell him so, due to the now unexpectedly passing test, and he
    can remove the '\''Test.Tasty.ExpectedFailure.expectFail'\'' marker.

    The module also provides '\''Test.Tasty.ExpectedFailure.ignoreTest'\'' to avoid
    running a test. Both funtions are implemented via the more general
    '\''Test.Tasty.ExpectedFailure.wrapTest'\'', which is also provided.

category:             Testing
abi:                  1b8b8104a8893ccf94f29f43bd22a4c0
exposed:              True
exposed-modules:      Test.Tasty.ExpectedFailure
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-expected-failure-0.12.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-expected-failure-0.12.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-expected-failure-0.12.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-expected-failure
hs-libraries:         HStasty-expected-failure-0.12.3-2B7tQ5MwpW3Qc4nmKIGHm
depends:
    base-4.17.2.1 tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5-FRQtZsdenVIBoQGCChJ79f
    unbounded-delays-0.1.1.1-9PQJht8VjI9BW2tiXlJWhX

haddock-interfaces:
    /usr/share/doc/haskell-tasty-expected-failure/html/tasty-expected-failure.haddock

haddock-html:         /usr/share/doc/haskell-tasty-expected-failure/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
